@@ -252,8 +252,8 @@ EWTPR <- function(n,m,nunique2,maxfollow2,untimes2,Time,Delta,dist2,markov_ind,c
 
   #--------------------------------------------------------
   # FOR COMPARISON WITH FORTRAN
-  random=runif(n*nunique2*nimp)
-  iran=1
+  #random=runif(n*nunique2*nimp)
+  #iran=1
   #--------------------------------------------------------
 
   ewtpr_time=rep(0,nimp)
@@ -590,11 +590,11 @@ EWTPR <- function(n,m,nunique2,maxfollow2,untimes2,Time,Delta,dist2,markov_ind,c
       sum=state_dist[1]
       for (k in 1:(m+1)) {
 
-        #if (runif(1) < sum | k==m) {
-        if (random[iran] < sum | k==m+1) {
+        if (runif(1) < sum | k==m+1) {
+        #if (random[iran] < sum | k==m+1) {
           state_dist[1:(m+1)]=0
           state_dist[k]=1
-          iran=iran+1
+          #iran=iran+1
           break
         #} else {
           #iran=iran+1
@@ -766,11 +766,11 @@ EWTPR <- function(n,m,nunique2,maxfollow2,untimes2,Time,Delta,dist2,markov_ind,c
         #
         sum=state_dist[1]
         for (k in 1:(m+1)) {
-          #if (runif(1) < sum | k==m) {
-          if (random[iran] < sum | k==m+1) {
+          if (runif(1) < sum | k==m+1) {
+          #if (random[iran] < sum | k==m+1) {
             state_dist[1:(m+1)]=0
             state_dist[k]=1
-            iran=iran+1
+            #iran=iran+1
             break
           #} else {
             #iran=iran+1
